@@ -1,6 +1,4 @@
-import os
 import typer
-from haskellian import either as E
 
 app = typer.Typer()
 
@@ -13,11 +11,11 @@ def callback(debug: bool = typer.Option(False, '--debug', help='Enable debug mod
     debugpy.wait_for_client()
 
 @app.command()
-def test(conn_str: str, verbose: bool = typer.Option(False, '-v', '--verbose')):
+def test(conn_str: str):
   """Performs some basic tests on `KV.of(conn_str)`"""
   import asyncio
   from dslog import Logger
-  from kv import KV, SQLiteKV
+  from kv import KV, SQLKV
   from kv.tests import test_bool, test_bytes, test_dict, test_float, test_int, test_list, test_str
   logger = Logger.click().prefix('[TEST]')
   async def tests():
@@ -25,53 +23,55 @@ def test(conn_str: str, verbose: bool = typer.Option(False, '-v', '--verbose')):
     for dtype, test in [(bool, test_bool), (bytes, test_bytes), (dict, test_dict), (float, test_float), (int, test_int), (list, test_list), (str, test_str)]:
       logger(f'Testing KV[{dtype.__name__}]...')
       kv = KV.of(conn_str, type=dtype)
-      e = await test(kv, logger=logger if verbose else Logger.empty())
-      if e.tag == 'left':
-        logger(f'--> ERROR:', e.value, level='ERROR')
-      else:
+      errors = await test(kv)
+      if not errors:
         logger(f'--> OK')
-      results.append(e)
-      if isinstance(kv, SQLiteKV):
-        os.remove(kv.db_path)
+      else:
+        logger(f'--> {len(errors)} errors', level='ERROR')
+        for e in errors:
+          logger(e, level='ERROR')
+      results.append(not errors)
+      
+      if isinstance(kv, SQLKV):
+        kv.Base.metadata.drop_all(kv.engine)
+        
     return results
 
   results = asyncio.run(tests())
-  if E.sequence(results).tag == 'left':
+  if any(not r for r in results):
     raise typer.Exit(1)
 
-def parse_type(type: str):
-  if type == 'dict':
-    return dict
-  if type == 'list':
-    return list
-  if type == 'set':
-    return set
-  if type == 'str':
-    return str
-  if type == 'int':
-    return int
-  if type == 'float':
-    return float
-  if type == 'bool':
-    return bool
-  if type == 'bytes':
-    return None
-  raise ValueError(f'Invalid type: {type}')
-
 @app.command()
 def serve(
   conn_str: str = typer.Argument(..., help='KV connection string'),
-  token: str = typer.Option('', '--token', help='Bearer token for authorization'),
+  secret: str = typer.Option('', '--secret', help='Secret token for authorization'),
   host: str = typer.Option('0.0.0.0', '--host'),
   port: int = typer.Option(8000, '-p', '--port'),
-  type: str = typer.Option('bytes', '--type', help='Datatype. Supports: dict, list, set, str, int, float, bool, bytes (default)'),
+  type: str = typer.Option('any', '--type', help='Datatype. Supports: dict, list, set, str, int, float, bool, bytes (default)'),
 ):
-  from kv import http, KV
+  from kv import ServerKV, KV, parse_type
   import uvicorn
 
   t = parse_type(type)
   print('Starting API with type:', type)
   kv = KV.of(conn_str, type=t)
-  app = http.ServerKV(kv, type=t, token=token or None)
+  app = ServerKV(kv, secret=secret or None, type=t)
 
-  uvicorn.run(app, host=host, port=port)
\ No newline at end of file
+  uvicorn.run(app, host=host, port=port)
+
+# @app.command()
+# def copy(
+#   input: str = typer.Option(..., '-i', '--input', help='Input KV connection string'),
+#   output: str = typer.Option(..., '-o', '--output', help='Output KV connection string'),
+#   verbose: bool = typer.Option(False, '-v', '--verbose'),
+#   type: str = typer.Option('bytes', '--type', help='Datatype. Supports: dict, list, set, str, int, float, bool, bytes (default)'),
+# ):
+#   from kv import KV, parse_type
+#   t = parse_type(type)
+#   import asyncio
+
+#   async def copy():
+#     inp = KV.of(input, t)
+#     out = KV.of(output, t)
+
+#   asyncio.run(copy())
\ No newline at end of file
